(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)



(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     41434,       1531]*)
(*NotebookOutlinePosition[     42827,       1574]*)
(*  CellTagsIndexPosition[     42783,       1570]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.
Make modifications to any definition using commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellLabel->False,
  ImageSize->{200, 200},
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section",
  CellHorizontalScrolling->True,
  ShowCellLabel->False],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text",
  CellHorizontalScrolling->True,
  ShowCellLabel->False],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PageHeaderLines->{True, True},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellHorizontalScrolling->True,
  ShowCellLabel->True,
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellFrame->{{1, 3}, {3, 1}},
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{23, 30}, {10, 20}},
  CellGroupingRules->"TitleGrouping",
  PageBreakBelow->False,
  CellFrameMargins->9,
  TextAlignment->Center,
  TextJustification->0,
  LineSpacing->{0.95, 0},
  CounterIncrements->"Title",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->22,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[1],
  Background->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Title", "Printout"],
  CellFrame->{{1, 3}, {3, 1}},
  ShowCellBracket->False,
  CellMargins->{{23, 30}, {10, 0}},
  CellGroupingRules->"TitleGrouping",
  CellFrameMargins->4,
  TextAlignment->Center,
  TextJustification->0,
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->22]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellFrame->{{0.5, 2}, {2, 0.5}},
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{23, 30}, {10, 30}},
  CellElementSpacings->{"CellMinHeight"->10},
  CellGroupingRules->"TitleGrouping",
  PageBreakBelow->False,
  CellFrameColor->RGBColor[0, 0, 0.700008],
  TextAlignment->Center,
  TextJustification->0,
  LineSpacing->{1, 1},
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.341176],
  Background->RGBColor[0.850004, 0.850004, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Subtitle", "Printout"],
  CellFrame->{{0.5, 2}, {2, 0.5}},
  ShowCellBracket->False,
  CellMargins->{{23, 30}, {10, 30}},
  CellElementSpacings->{"CellMinHeight"->10},
  CellGroupingRules->"TitleGrouping",
  CellFrameColor->RGBColor[0, 0, 0.700008],
  TextAlignment->Center,
  TextJustification->0,
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["MainSection"],
  CellFrame->{{0, 2}, {2, 0}},
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{20, 111}, {10, 20}},
  CellElementSpacings->{"ClosedCellHeight"->17,
  "ClosedGroupTopMargin"->20,
  "GroupIconTopMargin"->0},
  CellGroupingRules->{"SectionGrouping", 35},
  PageBreakBelow->False,
  CellFrameMargins->{{4, 4}, {1, 1}},
  CellFrameColor->RGBColor[0, 0, 0.4],
  TextJustification->0,
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontColor->RGBColor[0, 0, 0.200015],
  Background->RGBColor[0.850004, 0.850004, 1]],

Cell[StyleData["MainSection", "Printout"],
  CellMargins->{{Inherited, 111}, {Inherited, Inherited}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->False,
  CellDingbat->"\[GraySquare]",
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{40, 30}, {3, 10}},
  CellElementSpacings->{"ClosedGroupTopMargin"->10},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->13,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Section", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubSectionFirst"],
  CellFrame->{{0, 2}, {2, 0}},
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{23, 183}, {5, 20}},
  CellElementSpacings->{"ClosedGroupTopMargin"->20,
  "GroupIconTopMargin"->0},
  CellGroupingRules->{"SectionGrouping", 55},
  PageBreakBelow->False,
  CellFrameMargins->3,
  CellFrameColor->RGBColor[0, 0, 0.400015],
  TextAlignment->Left,
  TextJustification->0,
  FontFamily->"Helvetica",
  FontSize->13,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.850004, 0.850004, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["SubSectionFirst", "Printout"],
  CellFrame->{{0, 2}, {2, 0}},
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{23, 183}, {Inherited, 20}},
  CellElementSpacings->{"ClosedGroupTopMargin"->20,
  "GroupIconTopMargin"->0},
  CellFrameColor->RGBColor[0, 0, 0.400015],
  TextAlignment->Left,
  TextJustification->0,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellFrame->False,
  CellDingbat->"\[EmptySquare]",
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{40, 30}, {3, 10}},
  CellElementSpacings->{"ClosedGroupTopMargin"->15},
  CellGroupingRules->"NormalGrouping",
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{Inherited, Inherited}, {Inherited, 10}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[EmptySmallSquare]",
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{40, 30}, {3, 8}},
  CellGroupingRules->"NormalGrouping",
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Subsubsection", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Item"],
  CellDingbat->"\[FilledSmallCircle]",
  ShowCellBracket->False,
  CellMargins->{{50, 30}, {2, 0}},
  CellGroupingRules->"NormalGrouping",
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  FontFamily->"Helvetica",
  FontSize->11,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["Item", "Printout"]],

Cell["Null", "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Theorem"],
  ShowCellBracket->False,
  CellMargins->{{30, 5}, {2, 8}},
  CellGroupingRules->"NormalGrouping",
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {" T", 
            StyleBox[ "HEOREM ", FontSize -> 10, FontWeight -> "Bold"], 
            CounterBox[ "Theorem"]}]], None}, {None, None}},
  CounterIncrements->"Theorem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Theorem", "Printout"],
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}},
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Definition"],
  ShowCellBracket->False,
  CellMargins->{{30, 5}, {2, 8}},
  CellGroupingRules->"NormalGrouping",
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {" D", 
            StyleBox[ "EFINITION ", FontSize -> 10, FontWeight -> "Bold"], 
            CounterBox[ "Theorem"]}]], None}, {None, None}},
  CounterIncrements->"Theorem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Definition", "Printout"],
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Th-Env"],
  CellDingbat->"\[FilledSmallCircle]",
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{41, 5}, {2, 8}},
  CellGroupingRules->"NormalGrouping",
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Th-Env", "Printout"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{41, Inherited}, {Inherited, Inherited}},
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Math-Init"],
  CellFrame->False,
  CellDingbat->"\[FilledSquare]",
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{30, 5}, {2, 10}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {"Mathematica initialization"}]], None}, {None, None}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontTracking->"Plain",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Math-Init", "Printout"],
  CellDingbat->"\[FilledSquare]",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SolvedProblem"],
  CellFrame->False,
  CellDingbat->None,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{30, 5}, {2, 10}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {"S", 
            StyleBox[ "OLVED ", FontSize -> 10, FontWeight -> "Bold"], "P", 
            StyleBox[ "ROBLEM ", FontSize -> 10, FontWeight -> "Bold"], 
            CounterBox[ "Problem"]}]], None}, {None, None}},
  CounterIncrements->"Problem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0.700008, 0, 0],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False}],

Cell[StyleData["SolvedProblem", "Printout"],
  CellFrame->False,
  CellDingbat->None,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Problem"],
  CellFrame->False,
  CellDingbat->None,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{30, 5}, {2, 10}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {"P", 
            StyleBox[ "ROBLEM ", FontSize -> 10, FontWeight -> "Bold"], 
            CounterBox[ "Problem"]}]], None}, {None, None}},
  CounterIncrements->"Problem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0, 0, 0.700008],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Problem", "Printout"],
  CellFrame->False,
  CellDingbat->None,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  FontFamily->"Helvetica",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Experiment"],
  CellFrame->False,
  CellDingbat->None,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{30, 5}, {2, 10}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {"E", 
            StyleBox[ "XPERIMENT ", FontSize -> 10, FontWeight -> "Bold"], 
            CounterBox[ "Problem"]}]], None}, {None, None}},
  CounterIncrements->"Problem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->RGBColor[0, 0.500008, 1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Experiment", "Printout"],
  CellFrame->False,
  CellDingbat->None,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  FontFamily->"Helvetica",
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SubProblem"],
  CellFrame->False,
  CellDingbat->None,
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{30, 5}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 70},
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {"(", 
            CounterBox[ "SubProblem"], ") "}]], None}, {None, None}},
  CounterIncrements->"SubProblem",
  CounterAssignments->{{"ProblemInput", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False}],

Cell[StyleData["SubProblem", "Printout"],
  CellFrame->False,
  CellDingbat->None]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SubProblemText"],
  CellFrame->False,
  CellDingbat->None,
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{30, 5}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 70},
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {"(", 
            CounterBox[ "SubProblem"], ")"}], FontFamily -> "Helvetica", 
          FontSize -> 12, FontWeight -> "Bold", FontSlant -> "Plain"], 
        None}, {None, None}},
  CounterIncrements->"SubProblem",
  CounterAssignments->{{"ProblemInput", 0}},
  FontFamily->"Times",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False,
  "StrikeThrough"->False}],

Cell[StyleData["SubProblemText", "Printout"],
  CellFrame->False,
  CellDingbat->None,
  FontSize->12]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Solution"],
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{50, 5}, {2, 8}},
  CellGroupingRules->{"SectionGrouping", 79},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  CellFrameLabels->{{Cell[ 
          TextData[ {" S", 
            StyleBox[ "OLUTION", FontSize -> 10]}]], None}, {None, None}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Plain",
  FontColor->RGBColor[0.996109, 0, 0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["Solution", "Printout"],
  CellDingbat->"\[EmptySmallCircle]"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Sol-End"],
  ShowCellBracket->False,
  CellMargins->{{50, 5}, {5, 1}},
  CellGroupingRules->{"SectionGrouping", 80},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"\[EmptySmallCircle]"}]]}, {None, None}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Sol-End", "Printout"],
  FontWeight->"Bold"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["ProblemItem"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{65, 5}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 80},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["ProblemItem", "Printout"],
  CellDingbat->"\[FilledSmallCircle]",
  FontSlant->"Italic"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SubProblemItem"],
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{70, 5}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 81},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["SubProblemItem", "Printout"],
  FontSlant->"Italic"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SubSubProblemItem"],
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{75, 5}, {2, 2}},
  CellGroupingRules->{"SectionGrouping", 81},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  FontFamily->"Helvetica",
  FontSize->11,
  FontSlant->"Italic",
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False}],

Cell[StyleData["SubSubProblemItem", "Printout"],
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{75, Inherited}, {Inherited, 0}},
  CellHorizontalScrolling->True,
  FontFamily->"Helvetica",
  FontSlant->"Italic"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["ProblemInput"],
  CellMargins->{{30, 5}, {5, 5}},
  Evaluatable->True,
  CellGroupingRules->{"SectionGrouping", 75},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{25, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{Cell[ 
          TextData[ {"(", 
            CounterBox[ "ProblemInput"], ")"}]], None}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->StandardForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"ProblemInput",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["ProblemInput", "Printout"],
  ShowCellLabel->False,
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellMargins->{{70, 5}, {5, 5}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{25, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->StandardForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  CellMargins->{{70, 5}, {5, 5}},
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedInput"],
  CellMargins->{{70, 5}, {5, 5}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{25, Inherited}, {Inherited, Inherited}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "Section"], ".", 
            CounterBox[ "NumberedInput"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->StandardForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"NumberedInput",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["NumberedInput", "Printout"],
  CellMargins->{{70, 5}, {5, 5}},
  ShowCellLabel->False,
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{70, 5}, {5, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelPositioning->Left,
  CellLabelMargins->{{25, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->StandardForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Printout"],
  CellMargins->{{70, 5}, {5, 5}},
  ShowCellLabel->False,
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellDingbat->"\[LongDash]",
  CellMargins->{{70, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{25, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSize->11,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{70, 5}, {3, 3}},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{70, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{25, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  TextAlignment->Left,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  CellMargins->{{70, 50}, {2, 5}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{70, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  CellMargins->{{70, 10}, {0, 5}},
  ImageSize->{0.0625, 0.0625},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  FontSize->9]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  CellMargins->{{5, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontSlant->"Oblique",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  CellMargins->{{0, Inherited}, {Inherited, Inherited}},
  FontSize->9]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  ShowCellBracket->False,
  CellMargins->{{65, 5}, {Inherited, 4}},
  CellHorizontalScrolling->True,
  CellFrameLabels->{{None, Cell[ 
          TextData[ {""}]]}, {None, None}},
  TextJustification->1,
  LineSpacing->{1, 1},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  LineSpacing->{1, 1},
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["TextBox"],
  CellFrame->0.5,
  ShowCellBracket->False,
  CellMargins->{{5, 5}, {2, 2}},
  CellEditDuplicate->False,
  CellHorizontalScrolling->True,
  CellFrameColor->RGBColor[0, 0, 0.996109],
  CellFrameLabels->{{None, Cell[ 
          TextData[ {""}]]}, {None, None}},
  LineIndent->0,
  FrameBoxOptions->{BoxMargins->6},
  GridBoxOptions->{ColumnSpacings->0.5,
  ColumnWidths->Automatic,
  ColumnAlignments->{Left},
  GridFrame->False}],

Cell[StyleData["TextBox", "Printout"],
  CellMargins->{{5, 5}, {4, 4}},
  CellFrameColor->RGBColor[0, 0, 0.996109],
  FontSize->11]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Special Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  ShowCellBracket->False,
  CellMargins->{{55, 5}, {5, 5}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "Section"], ".", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultInputFormatType,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{55, 5}, {5, 5}},
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedFigure"],
  ShowCellBracket->False,
  CellMargins->{{55, 145}, {2, 10}},
  CellHorizontalScrolling->True,
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Figure ", 
            CounterBox[ "Section"], ".", 
            CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
  CounterIncrements->"NumberedFigure",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedFigure", "Printout"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["NumberedTable"],
  ShowCellBracket->False,
  CellMargins->{{55, 145}, {2, 10}},
  CellFrameLabels->{{None, None}, {Cell[ 
          TextData[ {"Table ", 
            CounterBox[ "Section"], ".", 
            CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
  TextAlignment->Center,
  CounterIncrements->"NumberedTable",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedTable", "Printout"],
  CellMargins->{{55, Inherited}, {Inherited, Inherited}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["1ColumnBox"],
  CellFrame->False,
  ShowCellBracket->True,
  CellMargins->{{5, 5}, {2, 8}},
  CellEditDuplicate->False,
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnSpacings->0.5,
  ColumnWidths->{0.7, 0.1},
  ColumnAlignments->{Left},
  GridFrame->True}],

Cell[StyleData["1ColumnBox", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnBox"],
  CellFrame->False,
  ShowCellBracket->True,
  CellMargins->{{5, 5}, {2, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnSpacings->0.5,
  ColumnWidths->{0.3, 0.45},
  ColumnAlignments->{Left},
  GridFrame->True}],

Cell[StyleData["2ColumnBox", "Printout"],
  CellMargins->{{5, 5}, {2, 8}},
  FontSize->11]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnSmallBox"],
  CellFrame->True,
  CellMargins->{{5, 5}, {2, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnSpacings->1.5,
  ColumnWidths->0.35,
  ColumnAlignments->{Right, Left}}],

Cell[StyleData["2ColumnSmallBox", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnBox"],
  CellFrame->True,
  ShowCellBracket->True,
  CellMargins->{{5, 5}, {2, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnWidths->0.25,
  ColumnAlignments->{Left},
  GridFrame->True}],

Cell[StyleData["3ColumnBox", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnSmallBox"],
  CellFrame->True,
  CellMargins->{{5, 5}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnSpacings->1,
  ColumnWidths->0.23,
  ColumnAlignments->{Right, Center, Left}}],

Cell[StyleData["3ColumnSmallBox", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnBox"],
  CellFrame->True,
  CellMargins->{{5, 5}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnWidths->{0.12, 0.2, 0.12, 0.2}}],

Cell[StyleData["4ColumnBox", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnBox"],
  CellFrame->True,
  CellMargins->{{5, 5}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnWidths->0.15}],

Cell[StyleData["5ColumnBox", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["6ColumnBox"],
  CellFrame->True,
  CellMargins->{{5, 5}, {0, 8}},
  CellHorizontalScrolling->True,
  LineIndent->0,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.700008, 0.700008, 1],
  FontVariations->{"Underline"->False,
  "StrikeThrough"->False},
  FrameBoxOptions->{BoxMargins->2},
  GridBoxOptions->{ColumnWidths->{0.1, 0.2, 0.1, 0.1, 0.2, 0.1}}],

Cell[StyleData["6ColumnBox", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable"],
  CellMargins->{{5, 5}, {0, 8}},
  CellHorizontalScrolling->True,
  GridBoxOptions->{ColumnWidths->{0.3, 0.5},
  ColumnAlignments->{Left}}],

Cell[StyleData["2ColumnTable", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  CellMargins->{{5, 5}, {0, 8}},
  CellHorizontalScrolling->True,
  GridBoxOptions->{ColumnWidths->0.3,
  ColumnAlignments->{Left}}],

Cell[StyleData["3ColumnTable", "Printout"],
  CellMargins->{{5, 5}, {0, 8}},
  FontSize->11]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontSize->10,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Times",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontVariations->{"Underline"->True}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontVariations->{"Underline"->True}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnLink", "Printout"],
  FontVariations->{"Underline"->True}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontVariations->{"Underline"->True}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontVariations->{"Underline"->True}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontVariations->{"Underline"->True}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["Placeholder", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->PrimaryPlaceholder,
  StyleMenuListing->None,
  DrawHighlighted->True],

Cell[StyleData["SelectionPlaceholder", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{0.6, 1},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 945}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{639, 820},
WindowMargins->{{295, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {54, 54}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"FirstPageFace"->Right},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 64, "Subtitle"],
Cell[1816, 55, 190, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[2031, 63, 42, 0, 59, "Section"],
Cell[2076, 65, 131, 3, 40, 31, 0, "StyleData", "All", "Working"],
Cell[2210, 70, 153, 4, 38, 32, 0, "StyleData", "All", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2400, 79, 92, 2, 59, "Section"],
Cell[2495, 83, 156, 4, 33, "Text"],
Cell[2654, 89, 585, 16, 40, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Open  ]],

Cell[CellGroupData[{
Cell[3276, 110, 38, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[3339, 114, 713, 24, 95, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}}],
Cell[4055, 140, 377, 11, 65, 36, 0, "StyleData", "Title", "Printout",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}}]
}, Open  ]],

Cell[CellGroupData[{
Cell[4469, 156, 750, 22, 96, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}}],
Cell[5222, 180, 481, 13, 96, 39, 0, "StyleData", "Subtitle", "Printout",
  CounterAssignments->{{"Chapter", 0}, {"Section", 0}, {"Equation", 0}, {
      "Figure", 0}}]
}, Open  ]],

Cell[CellGroupData[{
Cell[5740, 198, 608, 18, 67, 30, 0, "StyleData", "MainSection", "All"],
Cell[6351, 218, 101, 1, 70, 42, 0, "StyleData", "MainSection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[6489, 224, 520, 15, 46, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[7012, 241, 38, 0, 70, 38, 0, "StyleData", "Section", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7087, 246, 653, 20, 66, 34, 0, "StyleData", "SubSectionFirst", "All"],
Cell[7743, 268, 423, 12, 66, 46, 0, "StyleData", "SubSectionFirst", \
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8203, 285, 480, 14, 45, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[8686, 301, 99, 1, 45, 41, 0, "StyleData", "Subsection", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8822, 307, 371, 11, 43, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[9196, 320, 44, 0, 70, 44, 0, "StyleData", "Subsubsection", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9277, 325, 336, 11, 37, 23, 0, "StyleData", "Item", "All"],
Cell[9616, 338, 35, 0, 70, 35, 0, "StyleData", "Item", "Printout"],
Cell[9654, 340, 21, 0, 70, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9724, 346, 42, 0, 59, "Section"],
Cell[9769, 348, 246, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[10040, 356, 566, 15, 42, 26, 0, "StyleData", "Theorem", "All",
  CounterIncrements->"Theorem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}}],
Cell[10609, 373, 124, 2, 42, 38, 0, "StyleData", "Theorem", "Printout",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}}]
}, Open  ]],

Cell[CellGroupData[{
Cell[10770, 380, 572, 15, 42, 29, 0, "StyleData", "Definition", "All",
  CounterIncrements->"Theorem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}}],
Cell[11345, 397, 63, 1, 42, 41, 0, "StyleData", "Definition", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11445, 403, 422, 12, 42, 25, 0, "StyleData", "Th-Env", "All",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}}],
Cell[11870, 417, 156, 3, 42, 37, 0, "StyleData", "Th-Env", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12063, 425, 470, 14, 44, 28, 0, "StyleData", "Math-Init", "All"],
Cell[12536, 441, 96, 2, 44, 40, 0, "StyleData", "Math-Init", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12669, 448, 855, 24, 44, 32, 0, "StyleData", "SolvedProblem", "All",
  CounterIncrements->"Problem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}}],
Cell[13527, 474, 165, 5, 44, 44, 0, "StyleData", "SolvedProblem", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13729, 484, 772, 23, 44, 26, 0, "StyleData", "Problem", "All",
  CounterIncrements->"Problem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}}],
Cell[14504, 509, 186, 6, 44, 38, 0, "StyleData", "Problem", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14727, 520, 778, 23, 44, 29, 0, "StyleData", "Experiment", "All",
  CounterIncrements->"Problem",
  CounterAssignments->{{"ProblemInput", 0}, {"SubProblem", 0}}],
Cell[15508, 545, 189, 6, 44, 41, 0, "StyleData", "Experiment", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15734, 556, 635, 20, 36, 29, 0, "StyleData", "SubProblem", "All",
  CounterIncrements->"SubProblem",
  CounterAssignments->{{"ProblemInput", 0}}],
Cell[16372, 578, 82, 2, 36, 41, 0, "StyleData", "SubProblem", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16491, 585, 764, 23, 36, 33, 0, "StyleData", "SubProblemText", "All",
  CounterIncrements->"SubProblem",
  CounterAssignments->{{"ProblemInput", 0}}],
Cell[17258, 610, 102, 3, 36, 45, 0, "StyleData", "SubProblemText", \
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17397, 618, 504, 14, 42, 27, 0, "StyleData", "Solution", "All"],
Cell[17904, 634, 77, 1, 42, 39, 0, "StyleData", "Solution", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18018, 640, 362, 10, 38, 26, 0, "StyleData", "Sol-End", "All"],
Cell[18383, 652, 60, 1, 38, 38, 0, "StyleData", "Sol-End", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18480, 658, 366, 11, 36, 30, 0, "StyleData", "ProblemItem", "All"],
Cell[18849, 671, 104, 2, 36, 42, 0, "StyleData", "ProblemItem", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18990, 678, 369, 11, 36, 33, 0, "StyleData", "SubProblemItem", "All"],
Cell[19362, 691, 68, 1, 36, 45, 0, "StyleData", "SubProblemItem", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19467, 697, 371, 11, 35, 36, 0, "StyleData", "SubSubProblemItem", \
"All"],
Cell[19841, 710, 219, 5, 33, 48, 0, "StyleData", "SubSubProblemItem", \
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20097, 720, 633, 18, 42, 31, 0, "StyleData", "ProblemInput", "All",
  CounterIncrements->"ProblemInput"],
Cell[20733, 740, 83, 2, 40, 43, 0, "StyleData", "ProblemInput", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20853, 747, 485, 15, 42, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[21341, 764, 86, 2, 40, 36, 0, "StyleData", "Input", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21464, 771, 670, 19, 42, 32, 0, "StyleData", "NumberedInput", "All",
  CounterIncrements->"NumberedInput"],
Cell[22137, 792, 118, 3, 40, 44, 0, "StyleData", "NumberedInput", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22292, 800, 486, 14, 42, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[22781, 816, 111, 3, 41, 37, 0, "StyleData", "Output", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22929, 824, 570, 17, 39, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[23502, 843, 88, 2, 35, 38, 0, "StyleData", "Message", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23627, 850, 521, 15, 40, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[24151, 867, 86, 2, 70, 36, 0, "StyleData", "Print", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24274, 874, 389, 11, 40, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[24666, 887, 171, 4, 34, 39, 0, "StyleData", "Graphics", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24874, 896, 210, 6, 38, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[25087, 904, 112, 2, 37, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25248, 912, 39, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[25312, 916, 278, 8, 40, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[25593, 926, 74, 2, 39, 35, 0, "StyleData", "Text", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25704, 933, 455, 14, 53, 26, 0, "StyleData", "TextBox", "All"],
Cell[26162, 949, 131, 3, 56, 38, 0, "StyleData", "TextBox", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26342, 958, 57, 0, 59, "Section"],
Cell[26402, 960, 225, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[26652, 968, 385, 9, 42, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[27040, 979, 97, 2, 41, 47, 0, "StyleData", "NumberedEquation", \
"Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27174, 986, 393, 9, 67, 33, 0, "StyleData", "NumberedFigure", "All",
  CounterIncrements->"NumberedFigure"],
Cell[27570, 997, 45, 0, 67, 45, 0, "StyleData", "NumberedFigure", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27652, 1002, 381, 9, 67, 32, 0, "StyleData", "NumberedTable", "All",
  CounterIncrements->"NumberedTable"],
Cell[28036, 1013, 118, 2, 70, 44, 0, "StyleData", "NumberedTable", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[28191, 1020, 544, 18, 54, 29, 0, "StyleData", "1ColumnBox", "All"],
Cell[28738, 1040, 90, 2, 55, 41, 0, "StyleData", "1ColumnBox", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28865, 1047, 517, 17, 58, 29, 0, "StyleData", "2ColumnBox", "All"],
Cell[29385, 1066, 90, 2, 57, 41, 0, "StyleData", "2ColumnBox", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29512, 1073, 488, 15, 58, 34, 0, "StyleData", "2ColumnSmallBox", "All"],
Cell[30003, 1090, 95, 2, 70, 46, 0, "StyleData", "2ColumnSmallBox", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30135, 1097, 497, 16, 54, 29, 0, "StyleData", "3ColumnBox", "All"],
Cell[30635, 1115, 90, 2, 70, 41, 0, "StyleData", "3ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30762, 1122, 494, 15, 52, 34, 0, "StyleData", "3ColumnSmallBox", "All"],
Cell[31259, 1139, 95, 2, 70, 46, 0, "StyleData", "3ColumnSmallBox", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31391, 1146, 443, 13, 52, 29, 0, "StyleData", "4ColumnBox", "All"],
Cell[31837, 1161, 90, 2, 70, 41, 0, "StyleData", "4ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31964, 1168, 425, 13, 52, 29, 0, "StyleData", "5ColumnBox", "All"],
Cell[32392, 1183, 90, 2, 70, 41, 0, "StyleData", "5ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32519, 1190, 451, 13, 52, 29, 0, "StyleData", "6ColumnBox", "All"],
Cell[32973, 1205, 90, 2, 70, 41, 0, "StyleData", "6ColumnBox", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33100, 1212, 171, 4, 36, 31, 0, "StyleData", "2ColumnTable", "All"],
Cell[33274, 1218, 92, 2, 70, 43, 0, "StyleData", "2ColumnTable", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33403, 1225, 164, 4, 36, 31, 0, "StyleData", "3ColumnTable", "All"],
Cell[33570, 1231, 92, 2, 70, 43, 0, "StyleData", "3ColumnTable", "Printout"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33711, 1239, 49, 0, 59, "Section"],
Cell[33763, 1241, 123, 4, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[33889, 1247, 122, 4, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[34014, 1253, 127, 4, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[34178, 1262, 33, 0, 39, "Section"],
Cell[34214, 1264, 121, 3, 70, "Text"],
Cell[34338, 1269, 226, 5, 70, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[34567, 1276, 295, 7, 70, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[34865, 1285, 400, 9, 70, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35268, 1296, 387, 9, 70, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35658, 1307, 401, 9, 70, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[36096, 1321, 35, 0, 39, "Section"],
Cell[36134, 1323, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[36343, 1331, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[36648, 1341, 79, 1, 70, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[36742, 1345, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[36871, 1352, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[37190, 1362, 82, 1, 70, 43, 0, "StyleData", "MainBookLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37309, 1368, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[37649, 1379, 79, 1, 70, 40, 0, "StyleData", "AddOnLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37765, 1385, 345, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38113, 1396, 82, 1, 70, 43, 0, "StyleData", "RefGuideLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38232, 1402, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[38563, 1412, 88, 1, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[38688, 1418, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[39023, 1428, 90, 1, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[39162, 1435, 37, 0, 39, "Section"],
Cell[39202, 1437, 115, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[39342, 1444, 145, 5, 70, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[39490, 1451, 42, 0, 70, 42, 0, "StyleData", "Placeholder", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39569, 1456, 193, 6, 70, 39, 0, "StyleData", "SelectionPlaceholder", \
"All",
  StyleMenuListing->None],
Cell[39765, 1464, 51, 0, 70, 51, 0, "StyleData", "SelectionPlaceholder", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[39865, 1470, 36, 0, 39, "Section"],
Cell[39904, 1472, 305, 5, 70, "Text"],
Cell[40212, 1479, 314, 10, 70, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[40529, 1491, 106, 3, 70, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[40638, 1496, 151, 5, 70, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[40792, 1503, 108, 3, 70, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[40903, 1508, 179, 5, 70, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[41085, 1515, 115, 3, 70, "Text"],
Cell[41203, 1520, 96, 3, 70, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[41302, 1525, 104, 2, 70, 36, 0, "StyleData", "InlineCellEditing", "All",
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

